"""
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
P3D script : ShaperRandomColor
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Script Target : 
|~----------------------------------------------------------------------------~|

 This script affects : surfaces / shaper color

|~----------------------------------------------------------------------------~|

Compatible Versions : 
|~----------------------------------------------------------------------------~|

 This script is compatible with versions : 2022.0
 
|~----------------------------------------------------------------------------~|


Requirements : 
|~----------------------------------------------------------------------------~|

 Must have .P3D project (CurrentP3DSession) 

 Special conditions :
 Necessary Modules : random
 For help installing modules : https://docs.python.org/3/installing/index.html

|~----------------------------------------------------------------------------~|



Description :
|~----------------------------------------------------------------------------~|

 This script will associate each surface with a random color regardless of layers.

|~----------------------------------------------------------------------------~|


Usage:
|~----------------------------------------------------------------------------~|
 
 Classic use case in P3D :  Scripting/Execute Script -> choose script

|~----------------------------------------------------------------------------~|

Data output format :
|~----------------------------------------------------------------------------~|

 A console message will be presented to annonce the completion of the script.

|~----------------------------------------------------------------------------~|

"""


import random

from p3dsdk import ColorRgb, CurrentP3DSession, GeometryLayer


def random_value():
    return random.uniform(0.0, 1.0)


def random_rgb() -> ColorRgb:
    return ColorRgb(random_value(), random_value(), random_value())


def set_random_color_to_surfaces(geometry_layer_list: [GeometryLayer]):
    for layer in geometry_layer_list:
        surfaces = layer.list_surfaces()
        for surface in surfaces:
            surface.color = random_rgb()


with CurrentP3DSession(33900) as p3d:
    model = p3d.data.list_models()[0]  # get first model
    layers = model.list_geometry_layers(recursive=True)  # get all layers in model
    set_random_color_to_surfaces(layers)
    print("Surfaces in shaper now have random colors.")
